pub enum BayesianQuadratureError {
EmptyObservations,
ObservationLengthMismatch,
NonFiniteObservationNode,
NonFiniteObservationValue,
Conditioning(ConditioningError),
Posterior(PosteriorError),
MateriallyNegativePosteriorVariance {
value: f64,
tolerance: f64,
},
}Expand description
Errors raised while constructing a Bayesian quadrature posterior.
Variants
EmptyObservations
No function observations were supplied.
ObservationLengthMismatch
Observation nodes and function values have different lengths.
NonFiniteObservationNode
At least one observation node is not finite.
NonFiniteObservationValue
At least one observed function value is not finite.
Conditioning(ConditioningError)
Gaussian conditioning failed.
Posterior(PosteriorError)
The computed posterior could not be represented as a valid scalar Gaussian posterior.
MateriallyNegativePosteriorVariance
The posterior variance is negative by more than the documented roundoff tolerance.