pub enum ConditioningError {
ZeroDimension,
MatrixDimensionMismatch,
NonFiniteMatrixEntry,
NonFiniteJitter,
NegativeJitter,
NotPositiveDefinite,
RightHandSideDimensionMismatch,
NonFiniteRightHandSideEntry,
}Expand description
Errors raised while constructing or using a Gaussian conditioning system.
Variants
ZeroDimension
The requested matrix dimension is zero.
MatrixDimensionMismatch
The flattened matrix length does not equal dimension * dimension.
NonFiniteMatrixEntry
At least one matrix entry is not finite.
NonFiniteJitter
The jitter value is not finite.
NegativeJitter
The jitter value is negative.
NotPositiveDefinite
Cholesky factorization failed because the regularized matrix is not positive definite.
RightHandSideDimensionMismatch
The right-hand-side length does not equal the matrix dimension.
NonFiniteRightHandSideEntry
At least one right-hand-side entry is not finite.