pub enum LinearSolverError {
Show 13 variants
ZeroDimension,
MatrixDimensionMismatch,
VectorDimensionMismatch,
NonFiniteMatrixEntry,
NonFiniteVectorEntry,
NonFiniteTolerance,
NegativeTolerance,
EmptyCandidateDirections,
NonSymmetricSystemMatrix,
SystemMatrixNotPositiveDefinite,
NonSymmetricCovariance,
CovarianceNotPositiveSemidefinite,
DegenerateObservation,
}Expand description
Errors raised by probabilistic linear-system primitives.
Variants
ZeroDimension
The system dimension is zero.
MatrixDimensionMismatch
A flattened square matrix has the wrong length.
VectorDimensionMismatch
A vector has the wrong length.
NonFiniteMatrixEntry
At least one matrix entry is not finite.
NonFiniteVectorEntry
At least one vector entry is not finite.
NonFiniteTolerance
A solver tolerance is not finite.
NegativeTolerance
A solver tolerance is negative.
EmptyCandidateDirections
No candidate projection directions were supplied.
NonSymmetricSystemMatrix
The system matrix is not symmetric within numerical tolerance.
SystemMatrixNotPositiveDefinite
The system matrix is not positive definite.
NonSymmetricCovariance
The covariance matrix is not symmetric within numerical tolerance.
CovarianceNotPositiveSemidefinite
The covariance matrix is not positive semidefinite within numerical tolerance.
DegenerateObservation
The observation direction contains no remaining prior uncertainty.