ActiveDesignResult

Struct ActiveDesignResult 

pub struct ActiveDesignResult { /* private fields */ }
Result of a sequential active Bayesian-quadrature run.

Implementations

Source

impl ActiveDesignResult

pub fn nodes(&self) -> &[f64]

Final observation nodes, including actively selected points.

pub fn values(&self) -> &[f64]

Final observed function values.

pub fn remaining_candidates(&self) -> &[f64]

Candidates not selected during this run.

pub fn steps(&self) -> &[ActiveDesignStep]

Ordered active-evaluation history.

Examples found in repository?
examples/active_quadrature.rs (line 39)
15fn main() -> Result<(), Box<dyn std::error::Error>> {
16    let kernel = RbfKernel::new(1.0, 1.0)?;
17    let measure = GaussianMeasure::new(0.0, 1.0)?;
18    let quadrature = BayesianQuadrature::new(kernel, measure, 1.0e-10);
19    let active = ActiveBayesianQuadrature::new(quadrature);
20
21    // Start from three evaluations; allow up to six more from a fixed candidate grid,
22    // stopping early once the posterior variance of the integral drops below 1e-6.
23    let initial_nodes = [-1.0, 0.0, 1.0];
24    let initial_values: Vec<f64> = initial_nodes.iter().copied().map(integrand).collect();
25    let candidates: Vec<f64> = (0..=23).map(|i| -2.875 + 0.25 * f64::from(i)).collect();
26
27    let initial = quadrature.posterior(&initial_nodes, &initial_values)?;
28    println!("initial posterior variance = {:.3e}", initial.variance());
29
30    let result = active.run(
31        &initial_nodes,
32        &initial_values,
33        &candidates,
34        6,
35        1.0e-6,
36        integrand,
37    )?;
38
39    for step in result.steps() {
40        println!(
41            "x = {:+.3}  predicted reduction = {:.3e}  posterior variance = {:.3e}",
42            step.point(),
43            step.predicted_variance_reduction(),
44            step.posterior_variance(),
45        );
46    }
47
48    let exact = (1.0_f64 / 3.0).sqrt() * (-0.25_f64 / 3.0).exp();
49    let posterior = result.posterior();
50    println!("stopped because: {:?}", result.termination());
51    println!(
52        "E[I | y] = {:.6} ± {:.3e}   (exact {exact:.6})",
53        posterior.mean(),
54        posterior.standard_deviation(),
55    );
56    Ok(())
57}
pub const fn posterior(&self) -> ScalarNormalPosterior

Final integral posterior.

Examples found in repository?
examples/active_quadrature.rs (line 49)
15fn main() -> Result<(), Box<dyn std::error::Error>> {
16    let kernel = RbfKernel::new(1.0, 1.0)?;
17    let measure = GaussianMeasure::new(0.0, 1.0)?;
18    let quadrature = BayesianQuadrature::new(kernel, measure, 1.0e-10);
19    let active = ActiveBayesianQuadrature::new(quadrature);
20
21    // Start from three evaluations; allow up to six more from a fixed candidate grid,
22    // stopping early once the posterior variance of the integral drops below 1e-6.
23    let initial_nodes = [-1.0, 0.0, 1.0];
24    let initial_values: Vec<f64> = initial_nodes.iter().copied().map(integrand).collect();
25    let candidates: Vec<f64> = (0..=23).map(|i| -2.875 + 0.25 * f64::from(i)).collect();
26
27    let initial = quadrature.posterior(&initial_nodes, &initial_values)?;
28    println!("initial posterior variance = {:.3e}", initial.variance());
29
30    let result = active.run(
31        &initial_nodes,
32        &initial_values,
33        &candidates,
34        6,
35        1.0e-6,
36        integrand,
37    )?;
38
39    for step in result.steps() {
40        println!(
41            "x = {:+.3}  predicted reduction = {:.3e}  posterior variance = {:.3e}",
42            step.point(),
43            step.predicted_variance_reduction(),
44            step.posterior_variance(),
45        );
46    }
47
48    let exact = (1.0_f64 / 3.0).sqrt() * (-0.25_f64 / 3.0).exp();
49    let posterior = result.posterior();
50    println!("stopped because: {:?}", result.termination());
51    println!(
52        "E[I | y] = {:.6} ± {:.3e}   (exact {exact:.6})",
53        posterior.mean(),
54        posterior.standard_deviation(),
55    );
56    Ok(())
57}
pub const fn termination(&self) -> ActiveTermination

Reason the active design stopped.

Examples found in repository?
examples/active_quadrature.rs (line 50)
15fn main() -> Result<(), Box<dyn std::error::Error>> {
16    let kernel = RbfKernel::new(1.0, 1.0)?;
17    let measure = GaussianMeasure::new(0.0, 1.0)?;
18    let quadrature = BayesianQuadrature::new(kernel, measure, 1.0e-10);
19    let active = ActiveBayesianQuadrature::new(quadrature);
20
21    // Start from three evaluations; allow up to six more from a fixed candidate grid,
22    // stopping early once the posterior variance of the integral drops below 1e-6.
23    let initial_nodes = [-1.0, 0.0, 1.0];
24    let initial_values: Vec<f64> = initial_nodes.iter().copied().map(integrand).collect();
25    let candidates: Vec<f64> = (0..=23).map(|i| -2.875 + 0.25 * f64::from(i)).collect();
26
27    let initial = quadrature.posterior(&initial_nodes, &initial_values)?;
28    println!("initial posterior variance = {:.3e}", initial.variance());
29
30    let result = active.run(
31        &initial_nodes,
32        &initial_values,
33        &candidates,
34        6,
35        1.0e-6,
36        integrand,
37    )?;
38
39    for step in result.steps() {
40        println!(
41            "x = {:+.3}  predicted reduction = {:.3e}  posterior variance = {:.3e}",
42            step.point(),
43            step.predicted_variance_reduction(),
44            step.posterior_variance(),
45        );
46    }
47
48    let exact = (1.0_f64 / 3.0).sqrt() * (-0.25_f64 / 3.0).exp();
49    let posterior = result.posterior();
50    println!("stopped because: {:?}", result.termination());
51    println!(
52        "E[I | y] = {:.6} ± {:.3e}   (exact {exact:.6})",
53        posterior.mean(),
54        posterior.standard_deviation(),
55    );
56    Ok(())
57}