KernelIntegral

Trait KernelIntegral 

pub trait KernelIntegral<M> {
    // Required method
    fn kernel_integral(&self, measure: &M) -> f64;
}
Analytic double integral of a scalar kernel under a probability measure.

For a kernel k and probability measure p, this quantity is

kappa = double integral k(x, x') p(x) p(x') dx dx'.

The trait is implemented only for kernel/measure pairs with an explicit analytic contract.

Required Methods

fn kernel_integral(&self, measure: &M) -> f64

Evaluate the analytic double kernel integral.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors